@@ -339,7 +339,8 @@ class Timeline(urwid.Columns):
         if img:
             try:
                 status.placeholders[placeholder_index]._set_original_widget(
-                    graphics_widget(img, image_format=self.tui.options.image_format, corner_radius=10))
+                    graphics_widget(img, image_format=self.tui.options.image_format, corner_radius=10,
+                                    colors=self.tui.options.colors))
 
             except IndexError:
                 # ignore IndexErrors.
@@ -408,7 +409,8 @@ class StatusDetails(urwid.Pile):
                 pass
         if img:
             return (urwid.BoxAdapter(
-                graphics_widget(img, image_format=self.timeline.tui.options.image_format, corner_radius=10), rows))
+                graphics_widget(img, image_format=self.timeline.tui.options.image_format, corner_radius=10,
+                                colors=self.timeline.tui.options.colors), rows))
         else:
             placeholder = urwid.BoxAdapter(urwid.SolidFill(fill_char=" "), rows)
             self.status.placeholders.append(placeholder)
@@ -482,15 +484,16 @@ class StatusDetails(urwid.Pile):
                                 yield self.image_widget(m["url"], aspect=aspect)
                             yield urwid.Divider()
                         # video media may include a preview URL, show that as a fallback
-                        elif m["preview_url"].lower().endswith(('.jpg', '.jpeg', '.png', '.gif', '.svg', '.webp')):
-                            yield urwid.Text("")
-                            try:
-                                aspect = float(m["meta"]["small"]["aspect"])
-                            except Exception:
-                                aspect = None
-                            if image_support_enabled():
-                                yield self.image_widget(m["preview_url"], aspect=aspect)
-                            yield urwid.Divider()
+                        elif m["preview_url"]:
+                            if m["preview_url"].lower().endswith(('.jpg', '.jpeg', '.png', '.gif', '.svg', '.webp')):
+                                yield urwid.Text("")
+                                try:
+                                    aspect = float(m["meta"]["small"]["aspect"])
+                                except Exception:
+                                    aspect = None
+                                if image_support_enabled():
+                                    yield self.image_widget(m["preview_url"], aspect=aspect)
+                                yield urwid.Divider()
                         yield ("pack", url_to_widget(m["url"]))
 
             poll = status.original.data.get("poll")
